@@ -1,5 +1,5 @@
 from ._colors import get_srgb1, tripcolor
-from ._main import Plot, plot, savefig, show, show_colors, show_contours
+from ._main import Plotter, plot, plot_colors, plot_contours
 from .benchmark import show_kovesi_test_image, show_test_function
 from .create import create_colormap, find_max_srgb_radius, show_circular, show_linear
 
@@ -11,12 +11,10 @@ __all__ = [
     "find_max_srgb_radius",
     "create_colormap",
     "get_srgb1",
-    "show_colors",
-    "show_contours",
-    "show",
-    "savefig",
+    "plot_colors",
+    "plot_contours",
     "plot",
-    "Plot",
+    "Plotter",
     #
     "tripcolor",
 ]
